.. armsim Resources file

Resources
==================================

The first section has resources used to create the microprocessor simulator,
that means to simulate the MMU, instruction set, etc.
:ref:`arm-processor-links`

The next section contains the resources needed to simulate Atmel's AT9.
:ref:`at9-processor-links`

.. _arm-processor-links:

ARM Processor Links
-------------------

* `ARM Architecture Reference Manual <http://www.arm.com/miscPDFs/14128.pdf>`_
* `ARM9E-S Technical Reference Manual <http://www.atmel.com/dyn/resources/prod_documents/doc6178.pdf>`_

.. _at9-processor-links:

AT9 Controller Links
--------------------

* `AT91SAM9260 Datasheet <http://www.atmel.com/dyn/resources/prod_documents/doc6221.pdf>`_
